
import re
from mandaye import config
from mandaye.response import template_response

class MandayeFilter(object):
    """ Default Mandaye filter
    This class allows to filter the request (cookies, headers and the message-body)
    and the response (cookies, headers and message-body)
    """

    @staticmethod
    def on_request(env, values, request):
        target = env['target']
        referer = request.headers.getheader('referer')
        if referer:
            referer = referer.replace(env["HTTP_HOST"], target.hostname)
            request.headers.addheader("Referer", referer)
        origin = request.headers.getheader('origin')
        if origin:
            origin = origin.replace(env["HTTP_HOST"], target.hostname)
            request.headers.addheader("Origin", origin)
        # Add forwarded header like Apache
        request.headers.addheader('X-Forwarded-For', env['REMOTE_ADDR'])
        request.headers.addheader('X-Forwarded-Host', env['HTTP_HOST'])
        return request

    @staticmethod
    def on_response(env, values, request, response):
        target = env['target']
        # Modify cookies
        src_hostname = re.sub(":\d*$", "", env["HTTP_HOST"])
        for cookie in response.cookies.values():
            if cookie.has_key('domain'):
                cookie['domain'] = re.sub('^\.*%s$' % (target.hostname),
                        src_hostname, cookie['domain'])
        # Modify headers
        blacklist = ['transfer-encoding', 'content-length']
        for key, value in response.headers.iteritems():
            if key == 'location':
                location = value[0].replace(target.geturl(),
                        "%s://%s" % (env['mandaye.scheme'], env["HTTP_HOST"]))
                response.headers['location'] = [location]
        for name in blacklist:
            if response.headers.has_key(name):
                del response.headers[name]
        return response

    @staticmethod
    def addtoolbar(env, values, request, response):
        response.msg = response.msg.replace(
            '</head>',
            '<script src="%s/js/toolbar.js" type="text/javascript"></script>\
            <link rel="stylesheet" type="text/css" href="%s/css/toolbar.css">\
            </head>' % (config.static_url, config.static_url))
        return response

    @staticmethod
    def toolbar(env, values, request, response):
        return template_response("toolbar.html", values)
